@@ -26,6 +26,7 @@ pub use stream_broadcast::{
 /// prompts, and managing the agent lifecycle.
 ///
 /// See protocol docs: [Client](https://agentclientprotocol.com/protocol/overview#client)
+#[derive(Debug)]
 pub struct ClientSideConnection {
     conn: RpcConnection<ClientSide, AgentSide>,
 }
@@ -177,7 +178,7 @@ impl Agent for ClientSideConnection {
 /// are incoming vs outgoing from the client's perspective.
 ///
 /// See protocol docs: [Communication Model](https://agentclientprotocol.com/protocol/overview#communication-model)
-#[derive(Clone)]
+#[derive(Clone, Debug)]
 pub struct ClientSide;
 
 impl Side for ClientSide {
@@ -219,10 +220,10 @@ impl Side for ClientSide {
             }
             _ => {
                 if let Some(custom_method) = method.strip_prefix('_') {
-                    Ok(AgentRequest::ExtMethodRequest(ExtRequest {
-                        method: custom_method.into(),
-                        params: params.to_owned().into(),
-                    }))
+                    Ok(AgentRequest::ExtMethodRequest(ExtRequest::new(
+                        custom_method,
+                        params.to_owned().into(),
+                    )))
                 } else {
                     Err(Error::method_not_found())
                 }
@@ -239,10 +240,10 @@ impl Side for ClientSide {
                 .map_err(Into::into),
             _ => {
                 if let Some(custom_method) = method.strip_prefix('_') {
-                    Ok(AgentNotification::ExtNotification(ExtNotification {
-                        method: custom_method.into(),
-                        params: RawValue::from_string(params.get().to_string())?.into(),
-                    }))
+                    Ok(AgentNotification::ExtNotification(ExtNotification::new(
+                        custom_method,
+                        RawValue::from_string(params.get().to_string())?.into(),
+                    )))
                 } else {
                     Err(Error::method_not_found())
                 }
@@ -290,6 +291,7 @@ impl<T: Client> MessageHandler<ClientSide> for T {
                 let response = self.ext_method(args).await?;
                 Ok(ClientResponse::ExtMethodResponse(response))
             }
+            _ => Err(Error::method_not_found()),
         }
     }
 
@@ -301,6 +303,8 @@ impl<T: Client> MessageHandler<ClientSide> for T {
             AgentNotification::ExtNotification(args) => {
                 self.ext_notification(args).await?;
             }
+            // Ignore unknown notifications
+            _ => {}
         }
         Ok(())
     }
@@ -316,6 +320,7 @@ impl<T: Client> MessageHandler<ClientSide> for T {
 /// and sending session updates.
 ///
 /// See protocol docs: [Agent](https://agentclientprotocol.com/protocol/overview#agent)
+#[derive(Debug)]
 pub struct AgentSideConnection {
     conn: RpcConnection<AgentSide, ClientSide>,
 }
@@ -482,7 +487,7 @@ impl Client for AgentSideConnection {
 /// are incoming vs outgoing from the agent's perspective.
 ///
 /// See protocol docs: [Communication Model](https://agentclientprotocol.com/protocol/overview#communication-model)
-#[derive(Clone)]
+#[derive(Clone, Debug)]
 pub struct AgentSide;
 
 impl Side for AgentSide {
@@ -518,10 +523,10 @@ impl Side for AgentSide {
                 .map_err(Into::into),
             _ => {
                 if let Some(custom_method) = method.strip_prefix('_') {
-                    Ok(ClientRequest::ExtMethodRequest(ExtRequest {
-                        method: custom_method.into(),
-                        params: params.to_owned().into(),
-                    }))
+                    Ok(ClientRequest::ExtMethodRequest(ExtRequest::new(
+                        custom_method,
+                        params.to_owned().into(),
+                    )))
                 } else {
                     Err(Error::method_not_found())
                 }
@@ -538,10 +543,10 @@ impl Side for AgentSide {
                 .map_err(Into::into),
             _ => {
                 if let Some(custom_method) = method.strip_prefix('_') {
-                    Ok(ClientNotification::ExtNotification(ExtNotification {
-                        method: custom_method.into(),
-                        params: RawValue::from_string(params.get().to_string())?.into(),
-                    }))
+                    Ok(ClientNotification::ExtNotification(ExtNotification::new(
+                        custom_method,
+                        RawValue::from_string(params.get().to_string())?.into(),
+                    )))
                 } else {
                     Err(Error::method_not_found())
                 }
@@ -586,6 +591,7 @@ impl<T: Agent> MessageHandler<AgentSide> for T {
                 let response = self.ext_method(args).await?;
                 Ok(AgentResponse::ExtMethodResponse(response))
             }
+            _ => Err(Error::method_not_found()),
         }
     }
 
@@ -597,6 +603,8 @@ impl<T: Agent> MessageHandler<AgentSide> for T {
             ClientNotification::ExtNotification(args) => {
                 self.ext_notification(args).await?;
             }
+            // Ignore unknown notifications
+            _ => {}
         }
         Ok(())
     }
