@@ -33,6 +33,8 @@ pub struct SignableRequest<'a> {
 
 impl<'a> SignableRequest<'a> {
     /// Creates a new `SignableRequest`.
+    ///
+    /// NOTE: The `uri` is expected to already in encoded form.
     pub fn new(
         method: &'a str,
         uri: impl Into<Cow<'a, str>>,
@@ -96,7 +98,7 @@ pub enum SignableBody<'a> {
 }
 
 /// Formats the value using the given formatter. To print the body data, set the environment variable `LOG_SIGNABLE_BODY=true`.
-impl<'a> Debug for SignableBody<'a> {
+impl Debug for SignableBody<'_> {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
         let should_log_signable_body = std::env::var(LOG_SIGNABLE_BODY)
             .map(|v| v.eq_ignore_ascii_case("true"))
@@ -505,8 +507,9 @@ fn build_authorization_header(
 mod tests {
     use crate::date_time::test_parsers::parse_date_time;
     use crate::http_request::sign::{add_header, SignableRequest};
+    use crate::http_request::test::SigningSuiteTest;
     use crate::http_request::{
-        sign, test, SessionTokenMode, SignableBody, SignatureLocation, SigningInstructions,
+        sign, SessionTokenMode, SignableBody, SignatureLocation, SigningInstructions,
         SigningSettings,
     };
     use crate::sign::v4;
@@ -516,7 +519,6 @@ mod tests {
     use proptest::proptest;
     use std::borrow::Cow;
     use std::iter;
-    use std::time::Duration;
 
     macro_rules! assert_req_eq {
         (http: $expected:expr, $actual:expr) => {
@@ -537,294 +539,215 @@ mod tests {
         }
     }
 
-    #[test]
-    fn test_sign_vanilla_with_headers() {
-        let settings = SigningSettings::default();
-        let identity = &Credentials::for_tests().into();
-        let params = v4::SigningParams {
-            identity,
-            region: "us-east-1",
-            name: "service",
-            time: parse_date_time("20150830T123600Z").unwrap(),
-            settings,
-        }
-        .into();
-
-        let original = test::v4::test_request("get-vanilla-query-order-key-case");
-        let signable = SignableRequest::from(&original);
-        let out = sign(signable, &params).unwrap();
-        assert_eq!(
-            "5557820e7380d585310524bd93d51a08d7757fb5efd7344ee12088f2b0860947",
-            out.signature
-        );
-
-        let mut signed = original.as_http_request();
-        out.output.apply_to_request_http0x(&mut signed);
-
-        let expected = test::v4::test_signed_request("get-vanilla-query-order-key-case");
-        assert_req_eq!(expected, signed);
-    }
-
+    // Sigv4A suite tests
     #[cfg(feature = "sigv4a")]
-    mod sigv4a_tests {
-        use super::*;
-        use crate::http_request::canonical_request::{CanonicalRequest, StringToSign};
-        use crate::http_request::{sign, test, SigningParams};
-        use crate::sign::v4a;
-        use p256::ecdsa::signature::{Signature, Verifier};
-        use p256::ecdsa::{DerSignature, SigningKey};
-        use pretty_assertions::assert_eq;
-
-        fn new_v4a_signing_params_from_context(
-            test_context: &'_ test::v4a::TestContext,
-            signature_location: SignatureLocation,
-        ) -> SigningParams<'_> {
-            let mut params = v4a::SigningParams::from(test_context);
-            params.settings.signature_location = signature_location;
-
-            params.into()
-        }
-
-        fn run_v4a_test_suite(test_name: &str, signature_location: SignatureLocation) {
-            let tc = test::v4a::test_context(test_name);
-            let params = new_v4a_signing_params_from_context(&tc, signature_location);
-
-            let req = test::v4a::test_request(test_name);
-            let expected_creq = test::v4a::test_canonical_request(test_name, signature_location);
-            let signable_req = SignableRequest::from(&req);
-            let actual_creq = CanonicalRequest::from(&signable_req, &params).unwrap();
-
-            assert_eq!(expected_creq, actual_creq.to_string(), "creq didn't match");
-
-            let expected_string_to_sign =
-                test::v4a::test_string_to_sign(test_name, signature_location);
-            let hashed_creq = &v4::sha256_hex_string(actual_creq.to_string().as_bytes());
-            let actual_string_to_sign = StringToSign::new_v4a(
-                *params.time(),
-                params.region_set().unwrap(),
-                params.name(),
-                hashed_creq,
-            )
-            .to_string();
-
-            assert_eq!(
-                expected_string_to_sign, actual_string_to_sign,
-                "'string to sign' didn't match"
-            );
-
-            let out = sign(signable_req, &params).unwrap();
-            // Sigv4a signatures are non-deterministic, so we can't compare the signature directly.
-            out.output
-                .apply_to_request_http0x(&mut req.as_http_request());
-
-            let creds = params.credentials().unwrap();
-            let signing_key =
-                v4a::generate_signing_key(creds.access_key_id(), creds.secret_access_key());
-            let sig = DerSignature::from_bytes(&hex::decode(out.signature).unwrap()).unwrap();
-            let sig = sig
-                .try_into()
-                .expect("DER-style signatures are always convertible into fixed-size signatures");
-
-            let signing_key = SigningKey::from_bytes(signing_key.as_ref()).unwrap();
-            let peer_public_key = signing_key.verifying_key();
-            let sts = actual_string_to_sign.as_bytes();
-            peer_public_key.verify(sts, &sig).unwrap();
-        }
+    mod v4a_suite {
+        use crate::http_request::test::v4a::run_test_suite_v4a;
 
         #[test]
         fn test_get_header_key_duplicate() {
-            run_v4a_test_suite("get-header-key-duplicate", SignatureLocation::Headers);
+            run_test_suite_v4a("get-header-key-duplicate")
+        }
+
+        #[test]
+        #[ignore = "httpparse doesn't support parsing multiline headers since they are deprecated in RFC7230"]
+        fn test_get_header_value_multiline() {
+            run_test_suite_v4a("get-header-value-multiline")
         }
 
         #[test]
         fn test_get_header_value_order() {
-            run_v4a_test_suite("get-header-value-order", SignatureLocation::Headers);
+            run_test_suite_v4a("get-header-value-order")
         }
 
         #[test]
         fn test_get_header_value_trim() {
-            run_v4a_test_suite("get-header-value-trim", SignatureLocation::Headers);
+            run_test_suite_v4a("get-header-value-trim");
         }
 
         #[test]
         fn test_get_relative_normalized() {
-            run_v4a_test_suite("get-relative-normalized", SignatureLocation::Headers);
+            run_test_suite_v4a("get-relative-normalized");
         }
 
         #[test]
         fn test_get_relative_relative_normalized() {
-            run_v4a_test_suite(
-                "get-relative-relative-normalized",
-                SignatureLocation::Headers,
-            );
+            run_test_suite_v4a("get-relative-relative-normalized");
         }
 
         #[test]
         fn test_get_relative_relative_unnormalized() {
-            run_v4a_test_suite(
-                "get-relative-relative-unnormalized",
-                SignatureLocation::Headers,
-            );
+            run_test_suite_v4a("get-relative-relative-unnormalized");
         }
 
         #[test]
         fn test_get_relative_unnormalized() {
-            run_v4a_test_suite("get-relative-unnormalized", SignatureLocation::Headers);
+            run_test_suite_v4a("get-relative-unnormalized");
         }
 
         #[test]
         fn test_get_slash_dot_slash_normalized() {
-            run_v4a_test_suite("get-slash-dot-slash-normalized", SignatureLocation::Headers);
+            run_test_suite_v4a("get-slash-dot-slash-normalized");
         }
 
         #[test]
         fn test_get_slash_dot_slash_unnormalized() {
-            run_v4a_test_suite(
-                "get-slash-dot-slash-unnormalized",
-                SignatureLocation::Headers,
-            );
+            run_test_suite_v4a("get-slash-dot-slash-unnormalized");
         }
 
         #[test]
         fn test_get_slash_normalized() {
-            run_v4a_test_suite("get-slash-normalized", SignatureLocation::Headers);
+            run_test_suite_v4a("get-slash-normalized");
         }
 
         #[test]
         fn test_get_slash_pointless_dot_normalized() {
-            run_v4a_test_suite(
-                "get-slash-pointless-dot-normalized",
-                SignatureLocation::Headers,
-            );
+            run_test_suite_v4a("get-slash-pointless-dot-normalized");
         }
 
         #[test]
         fn test_get_slash_pointless_dot_unnormalized() {
-            run_v4a_test_suite(
-                "get-slash-pointless-dot-unnormalized",
-                SignatureLocation::Headers,
-            );
+            run_test_suite_v4a("get-slash-pointless-dot-unnormalized");
         }
 
         #[test]
         fn test_get_slash_unnormalized() {
-            run_v4a_test_suite("get-slash-unnormalized", SignatureLocation::Headers);
+            run_test_suite_v4a("get-slash-unnormalized");
         }
 
         #[test]
         fn test_get_slashes_normalized() {
-            run_v4a_test_suite("get-slashes-normalized", SignatureLocation::Headers);
+            run_test_suite_v4a("get-slashes-normalized");
         }
 
         #[test]
         fn test_get_slashes_unnormalized() {
-            run_v4a_test_suite("get-slashes-unnormalized", SignatureLocation::Headers);
+            run_test_suite_v4a("get-slashes-unnormalized");
+        }
+
+        #[test]
+        #[ignore = "relies on single encode of path segments"]
+        // rely on single encoding of path segments, i.e. string-to-sign contains %20 for spaces rather than %25%20 as it should.
+        // skipped until we add control over double_uri_encode in context.json
+        fn test_get_space_normalized() {
+            run_test_suite_v4a("get-space-normalized");
+        }
+
+        #[test]
+        #[ignore = "httpparse fails on unencoded spaces in path"]
+        // the input request has unencoded space ' ' in the path which fails to parse
+        fn test_get_space_unnormalized() {
+            run_test_suite_v4a("get-space-unnormalized");
         }
 
         #[test]
         fn test_get_unreserved() {
-            run_v4a_test_suite("get-unreserved", SignatureLocation::Headers);
+            run_test_suite_v4a("get-unreserved");
+        }
+
+        #[test]
+        #[ignore = "httparse fails on invalid uri character"]
+        // relies on /ሴ canonicalized as /%E1%88%B4 when it should be /%25%E1%25%88%25%B4
+        fn test_get_utf8() {
+            run_test_suite_v4a("get-utf8");
         }
 
         #[test]
         fn test_get_vanilla() {
-            run_v4a_test_suite("get-vanilla", SignatureLocation::Headers);
+            run_test_suite_v4a("get-vanilla");
         }
 
         #[test]
         fn test_get_vanilla_empty_query_key() {
-            run_v4a_test_suite(
-                "get-vanilla-empty-query-key",
-                SignatureLocation::QueryParams,
-            );
+            run_test_suite_v4a("get-vanilla-empty-query-key");
         }
 
         #[test]
         fn test_get_vanilla_query() {
-            run_v4a_test_suite("get-vanilla-query", SignatureLocation::QueryParams);
+            run_test_suite_v4a("get-vanilla-query");
+        }
+
+        #[test]
+        fn test_get_vanilla_query_order_encoded() {
+            run_test_suite_v4a("get-vanilla-query-order-encoded");
         }
 
         #[test]
         fn test_get_vanilla_query_order_key_case() {
-            run_v4a_test_suite(
-                "get-vanilla-query-order-key-case",
-                SignatureLocation::QueryParams,
-            );
+            run_test_suite_v4a("get-vanilla-query-order-key-case");
         }
 
         #[test]
         fn test_get_vanilla_query_unreserved() {
-            run_v4a_test_suite(
-                "get-vanilla-query-unreserved",
-                SignatureLocation::QueryParams,
-            );
+            run_test_suite_v4a("get-vanilla-query-unreserved");
+        }
+
+        #[test]
+        #[ignore = "httparse fails on invalid uri character"]
+        // relies on /ሴ canonicalized as /%E1%88%B4 when it should be /%25%E1%25%88%25%B4
+        fn test_get_vanilla_utf8_query() {
+            run_test_suite_v4a("get-vanilla-utf8-query");
         }
 
         #[test]
         fn test_get_vanilla_with_session_token() {
-            run_v4a_test_suite("get-vanilla-with-session-token", SignatureLocation::Headers);
+            run_test_suite_v4a("get-vanilla-with-session-token")
         }
 
         #[test]
         fn test_post_header_key_case() {
-            run_v4a_test_suite("post-header-key-case", SignatureLocation::Headers);
+            run_test_suite_v4a("post-header-key-case");
         }
 
         #[test]
         fn test_post_header_key_sort() {
-            run_v4a_test_suite("post-header-key-sort", SignatureLocation::Headers);
+            run_test_suite_v4a("post-header-key-sort");
         }
 
         #[test]
         fn test_post_header_value_case() {
-            run_v4a_test_suite("post-header-value-case", SignatureLocation::Headers);
+            run_test_suite_v4a("post-header-value-case");
         }
 
         #[test]
         fn test_post_sts_header_after() {
-            run_v4a_test_suite("post-sts-header-after", SignatureLocation::Headers);
+            run_test_suite_v4a("post-sts-header-after");
         }
 
         #[test]
         fn test_post_sts_header_before() {
-            run_v4a_test_suite("post-sts-header-before", SignatureLocation::Headers);
+            run_test_suite_v4a("post-sts-header-before");
         }
 
         #[test]
         fn test_post_vanilla() {
-            run_v4a_test_suite("post-vanilla", SignatureLocation::Headers);
+            run_test_suite_v4a("post-vanilla");
         }
 
         #[test]
         fn test_post_vanilla_empty_query_value() {
-            run_v4a_test_suite(
-                "post-vanilla-empty-query-value",
-                SignatureLocation::QueryParams,
-            );
+            run_test_suite_v4a("post-vanilla-empty-query-value");
         }
 
         #[test]
         fn test_post_vanilla_query() {
-            run_v4a_test_suite("post-vanilla-query", SignatureLocation::QueryParams);
+            run_test_suite_v4a("post-vanilla-query");
         }
 
         #[test]
         fn test_post_x_www_form_urlencoded() {
-            run_v4a_test_suite("post-x-www-form-urlencoded", SignatureLocation::Headers);
+            run_test_suite_v4a("post-x-www-form-urlencoded");
         }
 
         #[test]
         fn test_post_x_www_form_urlencoded_parameters() {
-            run_v4a_test_suite(
-                "post-x-www-form-urlencoded-parameters",
-                SignatureLocation::QueryParams,
-            );
+            run_test_suite_v4a("post-x-www-form-urlencoded-parameters");
         }
     }
 
     #[test]
     fn test_sign_url_escape() {
-        let test = "double-encode-path";
+        let test = SigningSuiteTest::v4("double-encode-path");
         let settings = SigningSettings::default();
         let identity = &Credentials::for_tests().into();
         let params = v4::SigningParams {
@@ -836,7 +759,7 @@ mod tests {
         }
         .into();
 
-        let original = test::v4::test_request(test);
+        let original = test.request();
         let signable = SignableRequest::from(&original);
         let out = sign(signable, &params).unwrap();
         assert_eq!(
@@ -847,40 +770,7 @@ mod tests {
         let mut signed = original.as_http_request();
         out.output.apply_to_request_http0x(&mut signed);
 
-        let expected = test::v4::test_signed_request(test);
-        assert_req_eq!(expected, signed);
-    }
-
-    #[test]
-    fn test_sign_vanilla_with_query_params() {
-        let settings = SigningSettings {
-            signature_location: SignatureLocation::QueryParams,
-            expires_in: Some(Duration::from_secs(35)),
-            ..Default::default()
-        };
-        let identity = &Credentials::for_tests().into();
-        let params = v4::SigningParams {
-            identity,
-            region: "us-east-1",
-            name: "service",
-            time: parse_date_time("20150830T123600Z").unwrap(),
-            settings,
-        }
-        .into();
-
-        let original = test::v4::test_request("get-vanilla-query-order-key-case");
-        let signable = SignableRequest::from(&original);
-        let out = sign(signable, &params).unwrap();
-        assert_eq!(
-            "ecce208e4b4f7d7e3a4cc22ced6acc2ad1d170ee8ba87d7165f6fa4b9aff09ab",
-            out.signature
-        );
-
-        let mut signed = original.as_http_request();
-        out.output.apply_to_request_http0x(&mut signed);
-
-        let expected =
-            test::v4::test_signed_request_query_params("get-vanilla-query-order-key-case");
+        let expected = test.signed_request(SignatureLocation::Headers);
         assert_req_eq!(expected, signed);
     }
 
@@ -1165,4 +1055,209 @@ mod tests {
         let sut = SignableBody::StreamingUnsignedPayloadTrailer;
         assert_eq!("StreamingUnsignedPayloadTrailer", format!("{sut:?}"));
     }
+
+    // v4 test suite
+    mod v4_suite {
+        use crate::http_request::test::run_test_suite_v4;
+
+        #[test]
+        fn test_get_header_key_duplicate() {
+            run_test_suite_v4("get-header-key-duplicate");
+        }
+
+        #[test]
+        #[ignore = "httpparse doesn't support parsing multiline headers since they are deprecated in RFC7230"]
+        fn test_get_header_value_multiline() {
+            run_test_suite_v4("get-header-value-multiline");
+        }
+
+        #[test]
+        fn test_get_header_value_order() {
+            run_test_suite_v4("get-header-value-order");
+        }
+
+        #[test]
+        fn test_get_header_value_trim() {
+            run_test_suite_v4("get-header-value-trim");
+        }
+
+        #[test]
+        fn test_get_relative_normalized() {
+            run_test_suite_v4("get-relative-normalized");
+        }
+
+        #[test]
+        fn test_get_relative_relative_normalized() {
+            run_test_suite_v4("get-relative-relative-normalized");
+        }
+
+        #[test]
+        fn test_get_relative_relative_unnormalized() {
+            run_test_suite_v4("get-relative-relative-unnormalized");
+        }
+
+        #[test]
+        fn test_get_relative_unnormalized() {
+            run_test_suite_v4("get-relative-unnormalized");
+        }
+
+        #[test]
+        fn test_get_slash_dot_slash_normalized() {
+            run_test_suite_v4("get-slash-dot-slash-normalized");
+        }
+
+        #[test]
+        fn test_get_slash_dot_slash_unnormalized() {
+            run_test_suite_v4("get-slash-dot-slash-unnormalized");
+        }
+
+        #[test]
+        fn test_get_slash_normalized() {
+            run_test_suite_v4("get-slash-normalized");
+        }
+
+        #[test]
+        fn test_get_slash_pointless_dot_normalized() {
+            run_test_suite_v4("get-slash-pointless-dot-normalized");
+        }
+
+        #[test]
+        fn test_get_slash_pointless_dot_unnormalized() {
+            run_test_suite_v4("get-slash-pointless-dot-unnormalized");
+        }
+
+        #[test]
+        fn test_get_slash_unnormalized() {
+            run_test_suite_v4("get-slash-unnormalized");
+        }
+
+        #[test]
+        fn test_get_slashes_normalized() {
+            run_test_suite_v4("get-slashes-normalized");
+        }
+
+        #[test]
+        fn test_get_slashes_unnormalized() {
+            run_test_suite_v4("get-slashes-unnormalized");
+        }
+
+        #[test]
+        #[ignore = "relies on single encode of path segments"]
+        // rely on single encoding of path segments, i.e. string-to-sign contains %20 for spaces rather than %25%20 as it should.
+        // skipped until we add control over double_uri_encode in context.json
+        fn test_get_space_normalized() {
+            run_test_suite_v4("get-space-normalized");
+        }
+
+        #[test]
+        #[ignore = "httpparse fails on unencoded spaces in path"]
+        // the input request has unencoded space ' ' in the path which fails to parse
+        fn test_get_space_unnormalized() {
+            run_test_suite_v4("get-space-unnormalized");
+        }
+
+        #[test]
+        fn test_get_unreserved() {
+            run_test_suite_v4("get-unreserved");
+        }
+
+        #[test]
+        #[ignore = "httparse fails on invalid uri character"]
+        // relies on /ሴ canonicalized as /%E1%88%B4 when it should be /%25%E1%25%88%25%B4
+        fn test_get_utf8() {
+            run_test_suite_v4("get-utf8");
+        }
+
+        #[test]
+        fn test_get_vanilla() {
+            run_test_suite_v4("get-vanilla");
+        }
+
+        #[test]
+        fn test_get_vanilla_empty_query_key() {
+            run_test_suite_v4("get-vanilla-empty-query-key");
+        }
+
+        #[test]
+        fn test_get_vanilla_query() {
+            run_test_suite_v4("get-vanilla-query");
+        }
+
+        #[test]
+        fn test_get_vanilla_query_order_encoded() {
+            run_test_suite_v4("get-vanilla-query-order-encoded");
+        }
+
+        #[test]
+        fn test_get_vanilla_query_order_key_case() {
+            run_test_suite_v4("get-vanilla-query-order-key-case");
+        }
+
+        #[test]
+        fn test_get_vanilla_query_unreserved() {
+            run_test_suite_v4("get-vanilla-query-unreserved");
+        }
+
+        #[test]
+        #[ignore = "httparse fails on invalid uri character"]
+        // relies on /ሴ canonicalized as /%E1%88%B4 when it should be /%25%E1%25%88%25%B4
+        fn test_get_vanilla_utf8_query() {
+            run_test_suite_v4("get-vanilla-utf8-query");
+        }
+
+        #[test]
+        fn test_get_vanilla_with_session_token() {
+            run_test_suite_v4("get-vanilla-with-session-token");
+        }
+
+        #[test]
+        fn test_post_header_key_case() {
+            run_test_suite_v4("post-header-key-case");
+        }
+
+        #[test]
+        fn test_post_header_key_sort() {
+            run_test_suite_v4("post-header-key-sort");
+        }
+
+        #[test]
+        fn test_post_header_value_case() {
+            run_test_suite_v4("post-header-value-case");
+        }
+
+        #[test]
+        fn test_post_sts_header_after() {
+            run_test_suite_v4("post-sts-header-after");
+        }
+
+        #[test]
+        fn test_post_sts_header_before() {
+            run_test_suite_v4("post-sts-header-before");
+        }
+
+        #[test]
+        fn test_post_vanilla() {
+            run_test_suite_v4("post-vanilla");
+        }
+
+        #[test]
+        fn test_post_vanilla_empty_query_value() {
+            run_test_suite_v4("post-vanilla-empty-query-value");
+        }
+
+        #[test]
+        fn test_post_vanilla_query() {
+            run_test_suite_v4("post-vanilla-query");
+        }
+
+        #[test]
+        fn test_post_x_www_form_urlencoded() {
+            run_test_suite_v4("post-x-www-form-urlencoded");
+        }
+
+        #[test]
+        fn test_post_x_www_form_urlencoded_parameters() {
+            run_test_suite_v4("post-x-www-form-urlencoded-parameters");
+        }
+    }
 }
