@@ -9,5 +9,14 @@
 
 #![allow(non_snake_case)]
 
+extern crate block;
+#[macro_use]
+extern crate bitflags;
+extern crate core_foundation;
+extern crate core_graphics_types;
+extern crate libc;
+#[macro_use]
+extern crate objc;
+
 pub mod base;
 pub mod foundation;
