@@ -66,6 +66,10 @@ pub mod scalar {
             [x1x1, x1x2, x1x3, x1x4,],
             [x2x1, x2x2, x2x3, x2x4,],
         }
+        pub const H_CPLX_M: usize = 0;
+        pub const H_CPLX_N: usize = 0;
+        pub const H_CPLX_UKR: [[gemm_common::microkernel::HMicroKernelFn<num_complex::Complex<T>>;
+            H_CPLX_N]; H_CPLX_M] = [];
     }
 }
 
@@ -78,6 +82,8 @@ pub mod fma {
         use core::arch::x86_64::*;
         use core::mem::transmute;
 
+        use gemm_common::pulp::u64x4;
+
         type T = f64;
         const N: usize = 4;
         const CPLX_N: usize = 2;
@@ -173,21 +179,81 @@ pub mod fma {
         microkernel_cplx_2step!(["fma"], 2, cplx_x1x2, 1, 2);
         microkernel_cplx_2step!(["fma"], 2, cplx_x1x3, 1, 3);
         microkernel_cplx_2step!(["fma"], 2, cplx_x1x4, 1, 4);
+        microkernel_cplx_2step!(["fma"], 2, cplx_x1x5, 1, 5);
+        microkernel_cplx_2step!(["fma"], 2, cplx_x1x6, 1, 6);
 
         microkernel_cplx_2step!(["fma"], 2, cplx_x2x1, 2, 1);
         microkernel_cplx_2step!(["fma"], 2, cplx_x2x2, 2, 2);
         microkernel_cplx_2step!(["fma"], 2, cplx_x2x3, 2, 3);
         microkernel_cplx_2step!(["fma"], 2, cplx_x2x4, 2, 4);
-
-        microkernel_cplx_2step!(["fma"], 2, cplx_x3x1, 3, 1);
-        microkernel_cplx_2step!(["fma"], 2, cplx_x3x2, 3, 2);
-        microkernel_cplx_2step!(["fma"], 2, cplx_x3x3, 3, 3);
-        microkernel_cplx_2step!(["fma"], 2, cplx_x3x4, 3, 4);
+        microkernel_cplx_2step!(["fma"], 2, cplx_x2x5, 2, 5);
+        microkernel_cplx_2step!(["fma"], 2, cplx_x2x6, 2, 6);
 
         microkernel_cplx_fn_array! {
-            [cplx_x1x1, cplx_x1x2, cplx_x1x3, cplx_x1x4,],
-            [cplx_x2x1, cplx_x2x2, cplx_x2x3, cplx_x2x4,],
-            [cplx_x3x1, cplx_x3x2, cplx_x3x3, cplx_x3x4,],
+            [cplx_x1x1, cplx_x1x2, cplx_x1x3, cplx_x1x4, cplx_x1x5, cplx_x1x6,],
+            [cplx_x2x1, cplx_x2x2, cplx_x2x3, cplx_x2x4, cplx_x2x5, cplx_x2x6,],
+        }
+
+        #[inline(always)]
+        unsafe fn mul_add(a: Pack, b: Pack, c: Pack) -> Pack {
+            let ab = transmute(a);
+            let xy = transmute(b);
+
+            let yx = _mm256_permute_pd::<0b0101>(xy);
+            let aa = _mm256_unpacklo_pd(ab, ab);
+            let bb = _mm256_unpackhi_pd(ab, ab);
+
+            transmute(_mm256_fmaddsub_pd(
+                aa,
+                xy,
+                _mm256_fmaddsub_pd(bb, yx, transmute(c)),
+            ))
+        }
+
+        #[inline(always)]
+        unsafe fn conj_mul_add(a: Pack, b: Pack, c: Pack) -> Pack {
+            let ab = transmute(a);
+            let xy = transmute(b);
+
+            let yx = _mm256_permute_pd::<0b0101>(xy);
+            let aa = _mm256_unpacklo_pd(ab, ab);
+            let bb = _mm256_unpackhi_pd(ab, ab);
+
+            transmute(_mm256_fmsubadd_pd(
+                aa,
+                xy,
+                _mm256_fmsubadd_pd(bb, yx, transmute(c)),
+            ))
+        }
+
+        static U64_MASKS: [u64x4; 3] = [
+            u64x4(0, 0, 0, 0),
+            u64x4(!0, !0, 0, 0),
+            u64x4(!0, !0, !0, !0),
+        ];
+
+        #[inline(always)]
+        unsafe fn partial_load(ptr: *const num_complex::Complex<T>, len: usize) -> Pack {
+            transmute(_mm256_maskload_pd(
+                ptr as *mut T,
+                transmute(*(U64_MASKS.as_ptr().add(len))),
+            ))
+        }
+
+        #[inline(always)]
+        unsafe fn reduce_sum(x: Pack) -> num_complex::Complex<T> {
+            let x: __m256d = transmute(x);
+            let x = _mm_add_pd(_mm256_castpd256_pd128(x), _mm256_extractf128_pd::<1>(x));
+            transmute(x)
+        }
+
+        horizontal_cplx_kernel!(["fma"], hx1x1, 1, 1);
+        horizontal_cplx_kernel!(["fma"], hx1x2, 1, 2);
+        horizontal_cplx_kernel!(["fma"], hx2x1, 2, 1);
+        horizontal_cplx_kernel!(["fma"], hx2x2, 2, 2);
+        hmicrokernel_cplx_fn_array! {
+            [hx1x1, hx1x2,],
+            [hx2x1, hx2x2,],
         }
     }
 }
@@ -348,8 +414,6 @@ pub mod avx512f {
         microkernel_cplx_2step!(["avx512f"], 2, cplx_x1x4, 1, 4);
         microkernel_cplx_2step!(["avx512f"], 2, cplx_x1x5, 1, 5);
         microkernel_cplx_2step!(["avx512f"], 2, cplx_x1x6, 1, 6);
-        microkernel_cplx_2step!(["avx512f"], 2, cplx_x1x7, 1, 7);
-        microkernel_cplx_2step!(["avx512f"], 2, cplx_x1x8, 1, 8);
 
         microkernel_cplx_2step!(["avx512f"], 2, cplx_x2x1, 2, 1);
         microkernel_cplx_2step!(["avx512f"], 2, cplx_x2x2, 2, 2);
@@ -357,8 +421,6 @@ pub mod avx512f {
         microkernel_cplx_2step!(["avx512f"], 2, cplx_x2x4, 2, 4);
         microkernel_cplx_2step!(["avx512f"], 2, cplx_x2x5, 2, 5);
         microkernel_cplx_2step!(["avx512f"], 2, cplx_x2x6, 2, 6);
-        microkernel_cplx_2step!(["avx512f"], 2, cplx_x2x7, 2, 7);
-        microkernel_cplx_2step!(["avx512f"], 2, cplx_x2x8, 2, 8);
 
         microkernel_cplx_2step!(["avx512f"], 2, cplx_x3x1, 3, 1);
         microkernel_cplx_2step!(["avx512f"], 2, cplx_x3x2, 3, 2);
@@ -366,13 +428,94 @@ pub mod avx512f {
         microkernel_cplx_2step!(["avx512f"], 2, cplx_x3x4, 3, 4);
         microkernel_cplx_2step!(["avx512f"], 2, cplx_x3x5, 3, 5);
         microkernel_cplx_2step!(["avx512f"], 2, cplx_x3x6, 3, 6);
-        microkernel_cplx_2step!(["avx512f"], 2, cplx_x3x7, 3, 7);
-        microkernel_cplx_2step!(["avx512f"], 2, cplx_x3x8, 3, 8);
+
+        microkernel_cplx_2step!(["avx512f"], 2, cplx_x4x1, 4, 1);
+        microkernel_cplx_2step!(["avx512f"], 2, cplx_x4x2, 4, 2);
+        microkernel_cplx_2step!(["avx512f"], 2, cplx_x4x3, 4, 3);
+        microkernel_cplx_2step!(["avx512f"], 2, cplx_x4x4, 4, 4);
+        microkernel_cplx_2step!(["avx512f"], 2, cplx_x4x5, 4, 5);
+        microkernel_cplx_2step!(["avx512f"], 2, cplx_x4x6, 4, 6);
 
         microkernel_cplx_fn_array! {
-            [cplx_x1x1, cplx_x1x2, cplx_x1x3, cplx_x1x4, cplx_x1x5, cplx_x1x6, cplx_x1x7, cplx_x1x8,],
-            [cplx_x2x1, cplx_x2x2, cplx_x2x3, cplx_x2x4, cplx_x2x5, cplx_x2x6, cplx_x2x7, cplx_x2x8,],
-            [cplx_x3x1, cplx_x3x2, cplx_x3x3, cplx_x3x4, cplx_x3x5, cplx_x3x6, cplx_x3x7, cplx_x3x8,],
+            [cplx_x1x1, cplx_x1x2, cplx_x1x3, cplx_x1x4, cplx_x1x5, cplx_x1x6,],
+            [cplx_x2x1, cplx_x2x2, cplx_x2x3, cplx_x2x4, cplx_x2x5, cplx_x2x6,],
+            [cplx_x3x1, cplx_x3x2, cplx_x3x3, cplx_x3x4, cplx_x3x5, cplx_x3x6,],
+            [cplx_x4x1, cplx_x4x2, cplx_x4x3, cplx_x4x4, cplx_x4x5, cplx_x4x6,],
+        }
+
+        #[inline(always)]
+        unsafe fn mul_add(a: Pack, b: Pack, c: Pack) -> Pack {
+            let ab = transmute(a);
+            let xy = transmute(b);
+
+            let yx = _mm512_permute_pd::<0b01010101>(xy);
+            let aa = _mm512_unpacklo_pd(ab, ab);
+            let bb = _mm512_unpackhi_pd(ab, ab);
+
+            transmute(_mm512_fmaddsub_pd(
+                aa,
+                xy,
+                _mm512_fmaddsub_pd(bb, yx, transmute(c)),
+            ))
+        }
+
+        #[inline(always)]
+        unsafe fn conj_mul_add(a: Pack, b: Pack, c: Pack) -> Pack {
+            let ab = transmute(a);
+            let xy = transmute(b);
+
+            let yx = _mm512_permute_pd::<0b01010101>(xy);
+            let aa = _mm512_unpacklo_pd(ab, ab);
+            let bb = _mm512_unpackhi_pd(ab, ab);
+
+            transmute(subadd_pd(aa, xy, subadd_pd(bb, yx, transmute(c))))
+        }
+
+        static U64_MASKS: [u8; 5] = [
+            0b00000000, //
+            0b00000011, //
+            0b00001111, //
+            0b00111111, //
+            0b11111111, //
+        ];
+
+        #[inline(always)]
+        unsafe fn partial_load(ptr: *const num_complex::Complex<T>, len: usize) -> Pack {
+            transmute(_mm512_maskz_loadu_pd(
+                transmute(*(U64_MASKS.as_ptr().add(len))),
+                ptr as *mut T,
+            ))
+        }
+
+        #[inline(always)]
+        unsafe fn reduce_sum(x: Pack) -> num_complex::Complex<T> {
+            let x = transmute(x);
+            let x = _mm256_add_pd(_mm512_castpd512_pd256(x), _mm512_extractf64x4_pd::<1>(x));
+            let x = _mm_add_pd(_mm256_castpd256_pd128(x), _mm256_extractf128_pd::<1>(x));
+            transmute(x)
+        }
+
+        horizontal_cplx_kernel!(["avx512f"], hx1x1, 1, 1);
+        horizontal_cplx_kernel!(["avx512f"], hx1x2, 1, 2);
+        horizontal_cplx_kernel!(["avx512f"], hx1x3, 1, 3);
+        horizontal_cplx_kernel!(["avx512f"], hx1x4, 1, 4);
+        horizontal_cplx_kernel!(["avx512f"], hx2x1, 2, 1);
+        horizontal_cplx_kernel!(["avx512f"], hx2x2, 2, 2);
+        horizontal_cplx_kernel!(["avx512f"], hx2x3, 2, 3);
+        horizontal_cplx_kernel!(["avx512f"], hx2x4, 2, 4);
+        horizontal_cplx_kernel!(["avx512f"], hx3x1, 3, 1);
+        horizontal_cplx_kernel!(["avx512f"], hx3x2, 3, 2);
+        horizontal_cplx_kernel!(["avx512f"], hx3x3, 3, 3);
+        horizontal_cplx_kernel!(["avx512f"], hx3x4, 3, 4);
+        horizontal_cplx_kernel!(["avx512f"], hx4x1, 4, 1);
+        horizontal_cplx_kernel!(["avx512f"], hx4x2, 4, 2);
+        horizontal_cplx_kernel!(["avx512f"], hx4x3, 4, 3);
+        horizontal_cplx_kernel!(["avx512f"], hx4x4, 4, 4);
+        hmicrokernel_cplx_fn_array! {
+            [hx1x1, hx1x2, hx1x3, hx1x4,],
+            [hx2x1, hx2x2, hx2x3, hx2x4,],
+            [hx3x1, hx3x2, hx3x3, hx3x4,],
+            [hx4x1, hx4x2, hx4x3, hx4x4,],
         }
     }
 }
@@ -489,5 +632,8 @@ pub mod neonfcma {
             [cplx_x2x1, cplx_x2x2, cplx_x2x3, cplx_x2x4,],
             [cplx_x3x1, cplx_x3x2, cplx_x3x3, cplx_x3x4,],
         }
+        pub const H_M: usize = 0;
+        pub const H_N: usize = 0;
+        pub const H_UKR: [[gemm_common::microkernel::HMicroKernelFn<T>; H_N]; H_M] = [];
     }
 }
