@@ -7,6 +7,8 @@
 
 pub mod gemm;
 pub mod microkernel;
+pub use half::f16;
 
 #[macro_use]
+#[allow(unused_imports)]
 extern crate gemm_common;
