@@ -5,6 +5,13 @@ use crate::{
     font_data::FontData,
     offset::{Offset, ResolveOffset},
 };
+use std::ops::Range;
+/// Return the minimum range of the table bytes
+///
+/// This trait is implemented in generated code, and we use this to get the minimum length/bytes of a table  
+pub trait MinByteRange {
+    fn min_byte_range(&self) -> Range<usize>;
+}
 
 #[derive(Clone)]
 /// Typed access to raw table data.
@@ -40,3 +47,18 @@ impl<'a, T> TableRef<'a, T> {
 impl<U, T: Format<U>> Format<U> for TableRef<'_, T> {
     const FORMAT: U = T::FORMAT;
 }
+
+impl<'a, T: MinByteRange> TableRef<'a, T> {
+    /// Return the minimum byte range of this table
+    pub fn min_byte_range(&self) -> Range<usize> {
+        self.shape.min_byte_range()
+    }
+
+    /// Return the minimum bytes of this table
+    pub fn min_table_bytes(&self) -> &'a [u8] {
+        self.offset_data()
+            .as_bytes()
+            .get(self.shape.min_byte_range())
+            .unwrap_or_default()
+    }
+}
