@@ -2,32 +2,16 @@ use super::buffer::*;
 use super::common::hb_codepoint_t;
 use super::hb_font_t;
 use super::ot_layout::*;
+use super::ot_shape_complex::MAX_COMBINING_MARKS;
 use super::ot_shape_plan::hb_ot_shape_plan_t;
-use super::ot_shaper::{ComposeFn, DecomposeFn, MAX_COMBINING_MARKS};
 use super::unicode::{hb_unicode_funcs_t, CharExt};
 
 pub struct hb_ot_shape_normalize_context_t<'a> {
     pub plan: &'a hb_ot_shape_plan_t,
     pub buffer: &'a mut hb_buffer_t,
     pub face: &'a hb_font_t<'a>,
-    pub decompose: DecomposeFn,
-    pub compose: ComposeFn,
-}
-
-impl hb_ot_shape_normalize_context_t<'_> {
-    pub(crate) fn override_decompose_and_compose(
-        &mut self,
-        decompose: Option<DecomposeFn>,
-        compose: Option<ComposeFn>,
-    ) {
-        if let Some(decompose) = decompose {
-            self.decompose = decompose;
-        }
-
-        if let Some(compose) = compose {
-            self.compose = compose;
-        }
-    }
+    pub decompose: fn(&hb_ot_shape_normalize_context_t, char) -> Option<(char, char)>,
+    pub compose: fn(&hb_ot_shape_normalize_context_t, char, char) -> Option<char>,
 }
 
 pub type hb_ot_shape_normalization_mode_t = i32;
@@ -74,7 +58,7 @@ pub const HB_OT_SHAPE_NORMALIZATION_MODE_DEFAULT: i32 = HB_OT_SHAPE_NORMALIZATIO
 //   - When a font does not support a character but supports its canonical
 //     decomposition, well, use the decomposition.
 //
-//   - The shapers can customize the compose and decompose functions to
+//   - The complex shapers can customize the compose and decompose functions to
 //     offload some of their requirements to the normalizer.  For example, the
 //     Indic shaper may want to disallow recomposing of two matras.
 
@@ -211,7 +195,7 @@ fn handle_variation_selector_cluster(
 ) {
     let face = ctx.face;
 
-    // Currently if there's a variation-selector we give-up on normalization, it's just too hard.
+    // TODO: Currently if there's a variation-selector we give-up, it's just too hard.
     let buffer = &mut ctx.buffer;
     while buffer.idx < end - 1 && buffer.successful {
         if buffer.cur(1).as_char().is_variation_selector() {
@@ -225,15 +209,6 @@ fn handle_variation_selector_cluster(
                 // Just pass on the two characters separately, let GSUB do its magic.
                 set_glyph(buffer.cur_mut(0), face);
                 buffer.next_glyph();
-
-                buffer.scratch_flags |= HB_BUFFER_SCRATCH_FLAG_HAS_VARIATION_SELECTOR_FALLBACK;
-
-                _hb_glyph_info_set_variation_selector(buffer.cur_mut(0), true);
-
-                if buffer.not_found_variation_selector.is_some() {
-                    _hb_glyph_info_clear_default_ignorable(buffer.cur_mut(0))
-                }
-
                 set_glyph(buffer.cur_mut(0), face);
                 buffer.next_glyph();
             }
@@ -304,11 +279,9 @@ pub fn _hb_ot_shape_normalize(
         plan,
         buffer,
         face,
-        decompose: decompose_unicode,
-        compose: compose_unicode,
+        decompose: plan.shaper.decompose.unwrap_or(decompose_unicode),
+        compose: plan.shaper.compose.unwrap_or(compose_unicode),
     };
-    ctx.override_decompose_and_compose(plan.shaper.decompose, plan.shaper.compose);
-
     let mut buffer = &mut ctx.buffer;
 
     let always_short_circuit = mode == HB_OT_SHAPE_NORMALIZATION_MODE_NONE;
