@@ -103,7 +103,7 @@
 //! # use taffy::*;
 //! pub trait RoundTree: TraverseTree {
 //!     /// Get the node's unrounded layout
-//!     fn get_unrounded_layout(&self, node_id: NodeId) -> &Layout;
+//!     fn get_unrounded_layout(&self, node_id: NodeId) -> Layout;
 //!     /// Get a reference to the node's final layout
 //!     fn set_final_layout(&mut self, node_id: NodeId, layout: &Layout);
 //! }
@@ -122,7 +122,7 @@
 //!     /// Get a debug label for the node (typically the type of node: flexbox, grid, text, image, etc)
 //!     fn get_debug_label(&self, node_id: NodeId) -> &'static str;
 //!     /// Get a reference to the node's final layout
-//!     fn get_final_layout(&self, node_id: NodeId) -> &Layout;
+//!     fn get_final_layout(&self, node_id: NodeId) -> Layout;
 //! }
 //! ```
 //!
@@ -135,6 +135,7 @@ use crate::style::{AvailableSpace, CoreStyle};
 use crate::style::{FlexboxContainerStyle, FlexboxItemStyle};
 #[cfg(feature = "grid")]
 use crate::style::{GridContainerStyle, GridItemStyle};
+use crate::CheapCloneStr;
 #[cfg(feature = "block_layout")]
 use crate::{BlockContainerStyle, BlockItemStyle};
 
@@ -173,10 +174,14 @@ pub trait TraverseTree: TraversePartialTree {}
 pub trait LayoutPartialTree: TraversePartialTree {
     /// The style type representing the core container styles that all containers should have
     /// Used when laying out the root node of a tree
-    type CoreContainerStyle<'a>: CoreStyle
+    type CoreContainerStyle<'a>: CoreStyle<CustomIdent = Self::CustomIdent>
     where
         Self: 'a;
 
+    /// String type for representing "custom identifiers" (for example, named grid lines or areas)
+    /// If you are unsure what to use here then consider `Arc<str>`.
+    type CustomIdent: CheapCloneStr;
+
     /// Get core style
     fn get_core_container_style(&self, node_id: NodeId) -> Self::CoreContainerStyle<'_>;
 
@@ -228,7 +233,7 @@ pub trait CacheTree {
 /// As indicated by it's dependence on `TraverseTree`, it required full recursive access to the tree.
 pub trait RoundTree: TraverseTree {
     /// Get the node's unrounded layout
-    fn get_unrounded_layout(&self, node_id: NodeId) -> &Layout;
+    fn get_unrounded_layout(&self, node_id: NodeId) -> Layout;
     /// Get a reference to the node's final layout
     fn set_final_layout(&mut self, node_id: NodeId, layout: &Layout);
 }
@@ -240,7 +245,7 @@ pub trait PrintTree: TraverseTree {
     /// Get a debug label for the node (typically the type of node: flexbox, grid, text, image, etc)
     fn get_debug_label(&self, node_id: NodeId) -> &'static str;
     /// Get a reference to the node's final layout
-    fn get_final_layout(&self, node_id: NodeId) -> &Layout;
+    fn get_final_layout(&self, node_id: NodeId) -> Layout;
 }
 
 #[cfg(feature = "flexbox")]
@@ -266,12 +271,12 @@ pub trait LayoutFlexboxContainer: LayoutPartialTree {
 /// Extends [`LayoutPartialTree`] with getters for the styles required for CSS Grid layout
 pub trait LayoutGridContainer: LayoutPartialTree {
     /// The style type representing the CSS Grid container's styles
-    type GridContainerStyle<'a>: GridContainerStyle
+    type GridContainerStyle<'a>: GridContainerStyle<CustomIdent = Self::CustomIdent>
     where
         Self: 'a;
 
     /// The style type representing each CSS Grid item's styles
-    type GridItemStyle<'a>: GridItemStyle
+    type GridItemStyle<'a>: GridItemStyle<CustomIdent = Self::CustomIdent>
     where
         Self: 'a;
 
